@@ -11,6 +11,7 @@ import (
 	"database/sql"
 	"embed"
 	"encoding/json"
+	"fmt"
 	"html/template"
 	"io"
 	"log"
@@ -26,6 +27,7 @@ import (
 
 	_ "github.com/lib/pq" // PostgreSQL driver
 	"github.com/oschwald/geoip2-golang"
+	"github.com/prometheus/client_golang/prometheus/promhttp"
 	"golang.org/x/text/cases"
 	"golang.org/x/text/language"
 
@@ -69,10 +71,12 @@ var (
 		{regexp.MustCompile(`\sandroid-.*vagrant@basebox-stretch64`), "F-Droid"},
 		{regexp.MustCompile(`\svagrant@bullseye`), "F-Droid"},
 		{regexp.MustCompile(`\sbuilduser@(archlinux|svetlemodry)`), "Arch (3rd party)"},
+		{regexp.MustCompile(`\ssyncthing@archlinux`), "Arch (3rd party)"},
 		{regexp.MustCompile(`@debian`), "Debian (3rd party)"},
 		{regexp.MustCompile(`@fedora`), "Fedora (3rd party)"},
 		{regexp.MustCompile(`\sbrew@`), "Homebrew (3rd party)"},
 		{regexp.MustCompile(`\sroot@buildkitsandbox`), "LinuxServer.io (3rd party)"},
+		{regexp.MustCompile(`\sports@freebsd`), "FreeBSD (3rd party)"},
 		{regexp.MustCompile(`.`), "Others"},
 	}
 )
@@ -196,6 +200,7 @@ func (cli *CLI) Run() error {
 	http.HandleFunc("/performance.json", srv.performanceHandler)
 	http.HandleFunc("/blockstats.json", srv.blockStatsHandler)
 	http.HandleFunc("/locations.json", srv.locationsHandler)
+	http.Handle("/metrics", promhttp.Handler())
 	http.Handle("/static/", http.FileServer(http.FS(statics)))
 
 	go srv.cacheRefresher()
@@ -289,6 +294,12 @@ func (s *server) locationsHandler(w http.ResponseWriter, _ *http.Request) {
 }
 
 func (s *server) newDataHandler(w http.ResponseWriter, r *http.Request) {
+	version := "fail"
+	defer func() {
+		// Version is "fail", "duplicate", "v2", "v3", ...
+		metricReportsTotal.WithLabelValues(version).Inc()
+	}()
+
 	defer r.Body.Close()
 
 	addr := r.Header.Get("X-Forwarded-For")
@@ -334,6 +345,7 @@ func (s *server) newDataHandler(w http.ResponseWriter, r *http.Request) {
 		if err.Error() == `pq: duplicate key value violates unique constraint "uniqueidjsonindex"` {
 			// We already have a report today for the same unique ID; drop
 			// this one without complaining.
+			version = "duplicate"
 			return
 		}
 		log.Println("insert:", err)
@@ -343,6 +355,8 @@ func (s *server) newDataHandler(w http.ResponseWriter, r *http.Request) {
 		http.Error(w, "Database Error", http.StatusInternalServerError)
 		return
 	}
+
+	version = fmt.Sprintf("v%d", rep.URVersion)
 }
 
 func (s *server) summaryHandler(w http.ResponseWriter, r *http.Request) {
